@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # coding: utf-8
 
 # Copyright (c) Jupyter Development Team.
@@ -18,44 +17,53 @@ import functools
 import pipes
 import re
 import shlex
+from shutil import which
 import subprocess
 import sys
 
+try:
+    from deprecation import deprecated
+except ImportError:
+    # shim deprecated to allow setuptools to find the version string in this file
+    deprecated = lambda *args, **kwargs: lambda *args, **kwargs: None
 
 # BEFORE importing distutils, remove MANIFEST. distutils doesn't properly
 # update it when the contents of directories change.
 if os.path.exists('MANIFEST'): os.remove('MANIFEST')
 
-
+from packaging.version import VERSION_PATTERN
 from setuptools import Command
 from setuptools.command.build_py import build_py
+from setuptools.config import StaticModule
 
 # Note: distutils must be imported after setuptools
-from distutils.command.sdist import sdist
 from distutils import log
 
+from setuptools.command.sdist import sdist
 from setuptools.command.develop import develop
 from setuptools.command.bdist_egg import bdist_egg
 
 try:
     from wheel.bdist_wheel import bdist_wheel
-except ImportError:
+except ImportError:  # pragma: no cover
     bdist_wheel = None
 
-if sys.platform == 'win32':
+if sys.platform == 'win32':   # pragma: no cover
     from subprocess import list2cmdline
 else:
     def list2cmdline(cmd_list):
         return ' '.join(map(pipes.quote, cmd_list))
 
 
-__version__ = '0.7.10'
+__version__ = '0.11.1'
 
 # ---------------------------------------------------------------------------
 # Top Level Variables
 # ---------------------------------------------------------------------------
 
 SEPARATORS = os.sep if os.altsep is None else os.sep + os.altsep
+VERSION_REGEX = re.compile(r"^\s*" + VERSION_PATTERN + r"\s*$", re.VERBOSE | re.IGNORECASE)
+
 
 if "--skip-npm" in sys.argv:
     print("Skipping npm install as requested.")
@@ -66,162 +74,204 @@ else:
 
 
 # ---------------------------------------------------------------------------
-# Public Functions
+# Core Functions
 # ---------------------------------------------------------------------------
 
-def get_version(file, name='__version__'):
-    """Get the version of the package from the given file by
-    executing it and extracting the given `name`.
+def wrap_installers(pre_develop=None, pre_dist=None, post_develop=None, post_dist=None, ensured_targets=None, skip_if_exists=None):
+    """Make a setuptools cmdclass that calls a prebuild function before installing.
+
+    Parameters
+    ----------
+    pre_develop: function
+        The function to call prior to the develop command.
+    pre_dist: function
+        The function to call prior to the sdist and wheel commands
+    post_develop: function
+        The function to call after the develop command.
+    post_dist: function
+        The function to call after the sdist and wheel commands.
+    ensured_targets: list
+        A list of local file paths that should exist when the dist commands are run
+    skip_if_exists: list
+        A list of local files whose presence causes the prebuild to skip
+
+    Notes
+    -----
+    For any function given, creates a new `setuptools` command that can be run separately,
+    e.g. `python setup.py pre_develop`.
+
+    Returns
+    -------
+    A cmdclass dictionary for setup args.
     """
-    path = os.path.realpath(file)
+    cmdclass = {}
+
+    def _make_command(name, func):
+        class _Wrapped(BaseCommand):
+            def run(self):
+                func()
+
+        _Wrapped.__name__ = name
+        func.__name__ = name
+        cmdclass[name] = _Wrapped
+
+    for name in ['pre_develop', 'post_develop', 'pre_dist', 'post_dist']:
+        if locals()[name]:
+            _make_command(name, locals()[name])
+
+    cmdclass['ensure_targets'] = ensure_targets(ensured_targets or [])
+
+    skips = skip_if_exists or []
+    should_skip = skips and all(Path(path).exists() for path in skips)
+
+    def _make_wrapper(klass, pre_build, post_build):
+        class _Wrapped(klass):
+            def run(self):
+                if pre_build and not should_skip:
+                    self.run_command(pre_build.__name__)
+                if klass != develop:
+                    self.run_command('ensure_targets')
+                klass.run(self)
+                if post_build and not should_skip:
+                    self.run_command(post_build.__name__)
+
+        cmdclass[klass.__name__] = _Wrapped
+
+    if pre_develop or post_develop:
+        _make_wrapper(develop, pre_develop, post_develop)
+
+    if pre_dist or post_dist or ensured_targets:
+        _make_wrapper(sdist, pre_dist, post_dist)
+        if bdist_wheel:
+            _make_wrapper(bdist_wheel, pre_dist, post_dist)
+
+    return cmdclass
+
+
+def npm_builder(path=None, build_dir=None, source_dir=None, build_cmd='build',
+                force=False, npm=None):
+    """Build function factory for managing an npm installation.
+
+    Note: The function is a no-op if the `--skip-npm` cli flag is used.
+
+    Parameters
+    ----------
+    path: str, optional
+        The base path of the node package. Defaults to the current directory.
+    build_dir: str, optional
+        The target build directory.  If this and source_dir are given,
+        the JavaScript will only be build if necessary.
+    source_dir: str, optional
+        The source code directory.
+    build_cmd: str, optional
+        The npm command to build assets to the build_dir.
+    npm: str or list, optional.
+        The npm executable name, or a tuple of ['node', executable].
+
+    Returns
+    -------
+    A build function to use with `wrap_installers`
+    """
+    def builder():
+        if skip_npm:
+            log.info('Skipping npm-installation')
+            return
+
+        node_package = path or os.path.abspath(os.getcwd())
+        node_modules = pjoin(node_package, 'node_modules')
+
+        is_yarn = os.path.exists(pjoin(node_package, 'yarn.lock'))
+        if is_yarn and not which('yarn'):
+            log.warn('yarn not found, ignoring yarn.lock file')
+            is_yarn = False
+
+        npm_cmd = npm
+
+        if npm is None:
+            if is_yarn:
+                npm_cmd = ['yarn']
+            else:
+                npm_cmd = ['npm']
+        elif isinstance(npm, str):
+            npm_cmd = [npm]
+
+        if not which(npm_cmd[0]):
+            log.error("`{0}` unavailable.  If you're running this command "
+                        "using sudo, make sure `{0}` is available to sudo"
+                        .format(npm_cmd[0]))
+            return
+
+        if build_dir and source_dir and not force:
+            should_build = is_stale(build_dir, source_dir)
+        else:
+            should_build = True
+
+        if should_build:
+            log.info('Installing build dependencies with npm.  This may '
+                        'take a while...')
+            run(npm_cmd + ['install'], cwd=node_package)
+            if build_cmd:
+                run(npm_cmd + ['run', build_cmd], cwd=node_package)
+
+    return builder
+
+# ---------------------------------------------------------------------------
+# Utility Functions
+# ---------------------------------------------------------------------------
+
+def get_data_files(data_specs, *, top=None, exclude=None):
+    """Expand data file specs into valid data files metadata.
+
+    Parameters
+    ----------
+    data_files_spec: list
+        A list of (path, dname, pattern) tuples where the path is the
+        `data_files` install path, dname is the source directory, and the
+        pattern is a glob pattern.
+    top: str, optional
+        The top directory
+    exclude: func, optional
+        Function used to test whether to exclude a file
+
+    Returns
+    -------
+    A valid list of data_files items.
+    """
+    return _get_data_files(data_specs, None, top=top, exclude=exclude)
+
+
+def get_version(fpath, name='__version__'):
+    """Get the version of the package from the given file by extracting the given `name`.
+    """
+    # Try to get it from a static import first
+    try:
+
+        module = StaticModule(fpath.replace(os.sep, '.').replace('.py', ''))
+        return getattr(module, name)
+    except Exception as e:
+        pass
+
+    path = os.path.realpath(fpath)
     version_ns = {}
     with io.open(path, encoding="utf8") as f:
         exec(f.read(), {}, version_ns)
     return version_ns[name]
 
 
-def ensure_python(specs):
-    """Given a list of range specifiers for python, ensure compatibility.
-    """
-    import warnings
-    warnings.warn(
-        'Deprecated, please use python_requires in the setup function directly',
-        category=DeprecationWarning
-    )
-    if not isinstance(specs, (list, tuple)):
-        specs = [specs]
-    v = sys.version_info
-    part = '%s.%s' % (v.major, v.minor)
-    for spec in specs:
-        if part == spec:
-            return
-        try:
-            if eval(part + spec):
-                return
-        except SyntaxError:
-            pass
-    raise ValueError('Python version %s unsupported' % part)
-
-
-def find_packages(top):
-    """
-    Find all of the packages.
-    """
-    import warnings
-    warnings.warn(
-        'Deprecated, please use setuptools.find_packages',
-        category=DeprecationWarning
-    )
-    from setuptools import find_packages as fp
-    return fp(top)
-
-
-def update_package_data(distribution):
-    """update build_py options to get package_data changes"""
-    build_py = distribution.get_command_obj('build_py')
-    build_py.finalize_options()
-
-
-class bdist_egg_disabled(bdist_egg):
-    """Disabled version of bdist_egg
-
-    Prevents setup.py install performing setuptools' default easy_install,
-    which it should never ever do.
-    """
-    def run(self):
-        sys.exit("Aborting implicit building of eggs. Use `pip install .` "
-                 " to install from source.")
-
-
-def create_cmdclass(prerelease_cmd=None, package_data_spec=None,
-                    data_files_spec=None, exclude=None):
-    """Create a command class with the given optional prerelease class.
-
-    Parameters
-    ----------
-    prerelease_cmd: (name, Command) tuple, optional
-        The command to run before releasing.
-    package_data_spec: dict, optional
-        A dictionary whose keys are the dotted package names and
-        whose values are a list of glob patterns.
-    data_files_spec: list, optional
-        A list of (path, dname, pattern) tuples where the path is the
-        `data_files` install path, dname is the source directory, and the
-        pattern is a glob pattern.
-    exclude: function
-        A function which takes a string filename and returns True if the
-        file should be excluded from package data and data files, False otherwise.
-
-    Notes
-    -----
-    We use specs so that we can find the files *after* the build
-    command has run.
-
-    The package data glob patterns should be relative paths from the package
-    folder containing the __init__.py file, which is given as the package
-    name.
-    e.g. `dict(foo=['./bar/*', './baz/**'])`
-
-    The data files directories should be absolute paths or relative paths
-    from the root directory of the repository.  Data files are specified
-    differently from `package_data` because we need a separate path entry
-    for each nested folder in `data_files`, and this makes it easier to
-    parse.
-    e.g. `('share/foo/bar', 'pkgname/bizz, '*')`
-    """
-    wrapped = [prerelease_cmd] if prerelease_cmd else []
-    if package_data_spec or data_files_spec:
-        wrapped.append('handle_files')
-
-    wrapper = functools.partial(_wrap_command, wrapped)
-    handle_files = _get_file_handler(package_data_spec, data_files_spec, exclude)
-    develop_handler = _get_develop_handler()
-
-    if 'bdist_egg' in sys.argv:
-        egg = wrapper(bdist_egg, strict=True)
-    else:
-        egg = bdist_egg_disabled
-
-    is_repo = os.path.exists('.git')
-
-    cmdclass = dict(
-        build_py=wrapper(build_py, strict=is_repo),
-        bdist_egg=egg,
-        sdist=wrapper(sdist, strict=True),
-        handle_files=handle_files,
-    )
-
-    if bdist_wheel:
-        cmdclass['bdist_wheel'] = wrapper(bdist_wheel, strict=True)
-
-    cmdclass['develop'] = wrapper(develop_handler, strict=True)
-    return cmdclass
-
-
-def command_for_func(func):
-    """Create a command that calls the given function."""
-
-    class FuncCommand(BaseCommand):
-
-        def run(self):
-            func()
-            update_package_data(self.distribution)
-
-    return FuncCommand
-
-
 def run(cmd, **kwargs):
     """Echo a command before running it."""
     log.info('> ' + list2cmdline(cmd))
     kwargs.setdefault('shell', os.name == 'nt')
-    if not isinstance(cmd, (list, tuple)) and os.name != 'nt':
-        cmd = shlex.split(cmd)
-    cmd_path = which(cmd[0])
-    if not cmd_path:
-        sys.exit("Aborting. Could not find cmd (%s) in path. "
-                 "If command is not expected to be in user's path, "
-                 "use an absolute path." % cmd[0])
-    cmd[0] = cmd_path
+    if not isinstance(cmd, (list, tuple)):
+        cmd = shlex.split(cmd, posix=os.name!='nt')
+    if not os.path.isabs(cmd[0]):
+        # If a command is not an absolute path find it first.
+        cmd_path = which(cmd[0])
+        if not cmd_path:
+            raise ValueError("Aborting. Could not find cmd (%s) in path. "
+                    "If command is not expected to be in user's path, "
+                    "use an absolute path." % cmd[0])
+        cmd[0] = cmd_path
     return subprocess.check_call(cmd, **kwargs)
 
 
@@ -254,10 +304,7 @@ class BaseCommand(Command):
 
 def combine_commands(*commands):
     """Return a Command that combines several commands."""
-
-    class CombinedCommand(Command):
-        user_options = []
-
+    class CombinedCommand(BaseCommand):
         def initialize_options(self):
             self.commands = []
             for C in commands:
@@ -322,87 +369,6 @@ def mtime(path):
     return os.stat(path).st_mtime
 
 
-def install_npm(path=None, build_dir=None, source_dir=None, build_cmd='build',
-                force=False, npm=None):
-    """Return a Command for managing an npm installation.
-
-    Note: The command is skipped if the `--skip-npm` flag is used.
-
-    Parameters
-    ----------
-    path: str, optional
-        The base path of the node package. Defaults to the current directory.
-    build_dir: str, optional
-        The target build directory.  If this and source_dir are given,
-        the JavaScript will only be build if necessary.
-    source_dir: str, optional
-        The source code directory.
-    build_cmd: str, optional
-        The npm command to build assets to the build_dir.
-    npm: str or list, optional.
-        The npm executable name, or a tuple of ['node', executable].
-    """
-
-    class NPM(BaseCommand):
-        description = 'install package.json dependencies using npm'
-
-        def run(self):
-            if skip_npm:
-                log.info('Skipping npm-installation')
-                return
-            node_package = path or os.path.abspath(os.getcwd())
-            node_modules = pjoin(node_package, 'node_modules')
-            is_yarn = os.path.exists(pjoin(node_package, 'yarn.lock'))
-
-            npm_cmd = npm
-
-            if npm is None:
-                if is_yarn:
-                    npm_cmd = ['yarn']
-                else:
-                    npm_cmd = ['npm']
-
-            if not which(npm_cmd[0]):
-                log.error("`{0}` unavailable.  If you're running this command "
-                          "using sudo, make sure `{0}` is available to sudo"
-                          .format(npm_cmd[0]))
-                return
-
-            if build_dir and source_dir and not force:
-                should_build = is_stale(build_dir, source_dir)
-            else:
-                should_build = True
-
-            if should_build:
-                log.info('Installing build dependencies with npm.  This may '
-                         'take a while...')
-                run(npm_cmd + ['install'], cwd=node_package)
-                if build_cmd:
-                    run(npm_cmd + ['run', build_cmd], cwd=node_package)
-
-    return NPM
-
-
-def ensure_targets(targets):
-    """Return a Command that checks that certain files exist.
-
-    Raises a ValueError if any of the files are missing.
-
-    Note: The check is skipped if the `--skip-npm` flag is used.
-    """
-
-    class TargetsCheck(BaseCommand):
-        def run(self):
-            if skip_npm:
-                log.info('Skipping target checks')
-                return
-            missing = [t for t in targets if not os.path.exists(t)]
-            if missing:
-                raise ValueError(('missing files: %s' % missing))
-
-    return TargetsCheck
-
-
 def skip_if_exists(paths, CommandClass):
     """Skip a command if list of paths exists."""
     def should_skip():
@@ -426,65 +392,236 @@ def skip_if_exists(paths, CommandClass):
     return SkipIfExistCommand
 
 
-# `shutils.which` function copied verbatim from the Python-3.3 source.
-def which(cmd, mode=os.F_OK | os.X_OK, path=None):
-    """Given a command, mode, and a PATH string, return the path which
-    conforms to the given mode on the PATH, or None if there is no such
-    file.
-    `mode` defaults to os.F_OK | os.X_OK. `path` defaults to the result
-    of os.environ.get("PATH"), or can be overridden with a custom search
-    path.
+def ensure_targets(targets):
+    """Return a Command that checks that certain files exist.
+
+    Raises a ValueError if any of the files are missing.
+
+    Note: The check is skipped if the `--skip-npm` flag is used.
     """
+    class TargetsCheck(BaseCommand):
+        def run(self):
+            if skip_npm:
+                log.info('Skipping target checks')
+                return
+            missing = [t for t in targets if not os.path.exists(t)]
+            if missing:
+                raise ValueError(('missing files: %s' % missing))
 
-    # Check that a given file can be accessed with the correct mode.
-    # Additionally check that `file` is not a directory, as on Windows
-    # directories pass the os.access check.
-    def _access_check(fn, mode):
-        return (os.path.exists(fn) and os.access(fn, mode) and
-                not os.path.isdir(fn))
+    return TargetsCheck
 
-    # Short circuit. If we're given a full path which matches the mode
-    # and it exists, we're done here.
-    if _access_check(cmd, mode):
-        return cmd
 
-    path = (path or os.environ.get("PATH", os.defpath)).split(os.pathsep)
+# ---------------------------------------------------------------------------
+# Deprecated Functions
+# ---------------------------------------------------------------------------
 
-    if sys.platform == "win32":
-        # The current directory takes precedence on Windows.
-        if os.curdir not in path:
-            path.insert(0, os.curdir)
+@deprecated(deprecated_in="0.11", removed_in="2.0", current_version=__version__,
+            details="Parse the version info as described in `get_version_info` docstring")
+def get_version_info(version_str):
+    """DEPRECATED: Get a version info tuple given a version string
 
-        # PATHEXT is necessary to check on Windows.
-        pathext = os.environ.get("PATHEXT", "").split(os.pathsep)
-        # See if the given file matches any of the expected path extensions.
-        # This will allow us to short circuit when given "python.exe".
-        matches = [cmd for ext in pathext if cmd.lower().endswith(ext.lower())]
-        # If it does match, only test that one, otherwise we have to try
-        # others.
-        files = [cmd] if matches else [cmd + ext.lower() for ext in pathext]
+    Use something like the following instead:
+
+    ```
+    import re
+
+    # Version string must appear intact for tbump versioning
+    __version__ = '1.4.0.dev0'
+
+    # Build up version_info tuple for backwards compatibility
+    pattern = r'(?P<major>\d+).(?P<minor>\d+).(?P<patch>\d+)(?P<rest>.*)'
+    match = re.match(pattern, __version__)
+    parts = [int(match[part]) for part in ['major', 'minor', 'patch']]
+    if match['rest']:
+    parts.append(match['rest'])
+    version_info = tuple(parts)
+    ```
+    """
+    match = VERSION_REGEX.match(version_str)
+    if not match:
+        raise ValueError(f'Invalid version "{version_str}"')
+    release = match['release']
+    version_info = [int(p) for p in release.split('.')]
+    if release != version_str:
+        version_info.append(version_str[len(release):])
+    return tuple(version_info)
+
+
+@deprecated(deprecated_in="0.8", removed_in="1.0", current_version=__version__,
+            details="Use `BaseCommand` directly instead")
+def command_for_func(func):
+    """Create a command that calls the given function."""
+    class FuncCommand(BaseCommand):
+
+        def run(self):
+            func()
+            update_package_data(self.distribution)
+
+    return FuncCommand
+
+
+@deprecated(deprecated_in="0.7", removed_in="1.0", current_version=__version__,
+            details="Use `setuptools` `python_requires` instead")
+def ensure_python(specs):
+    """Given a list of range specifiers for python, ensure compatibility.
+    """
+    if sys.version_info >= (3, 10):
+        raise RuntimeError("ensure_python is deprecated and not compatible with Python 3.10+")
+    if not isinstance(specs, (list, tuple)):
+        specs = [specs]
+    v = sys.version_info
+    part = '%s.%s' % (v.major, v.minor)
+    for spec in specs:
+        if part == spec:
+            return
+        try:
+            if eval(part + spec):
+                return
+        except SyntaxError:
+            pass
+    raise ValueError('Python version %s unsupported' % part)
+
+
+@deprecated(deprecated_in="0.7", removed_in="1.0", current_version=__version__,
+            details="Use `setuptools.find_packages` instead")
+def find_packages(top):
+    """
+    Find all of the packages.
+    """
+    from setuptools import find_packages as fp
+    return fp(top)
+
+
+@deprecated(deprecated_in="0.8", removed_in="1.0", current_version=__version__,
+            details="Use `use_package_data=True` and `MANIFEST.in` instead")
+def update_package_data(distribution):
+    """update build_py options to get package_data changes"""
+    build_py = distribution.get_command_obj('build_py')
+    build_py.finalize_options()
+
+
+@deprecated(deprecated_in="0.8", removed_in="1.0", current_version=__version__,
+            details="Not needed")
+class bdist_egg_disabled(bdist_egg):
+    """Disabled version of bdist_egg
+
+    Prevents setup.py install performing setuptools' default easy_install,
+    which it should never ever do.
+    """
+    def run(self):
+        sys.exit("Aborting implicit building of eggs. Use `pip install .` "
+                 " to install from source.")
+
+
+@deprecated(deprecated_in="0.8", removed_in="1.0", current_version=__version__,
+            details=""""
+Use `wrap_installers` to handle prebuild steps in cmdclass.
+Use `get_data_files` to handle data files.
+Use `include_package_data=True` and `MANIFEST.in` for package data.
+""")
+def create_cmdclass(prerelease_cmd=None, package_data_spec=None,
+                    data_files_spec=None, exclude=None):
+    """Create a command class with the given optional prerelease class.
+
+    Parameters
+    ----------
+    prerelease_cmd: (name, Command) tuple, optional
+        The command to run before releasing.
+    package_data_spec: dict, optional
+        A dictionary whose keys are the dotted package names and
+        whose values are a list of glob patterns.
+    data_files_spec: list, optional
+        A list of (path, dname, pattern) tuples where the path is the
+        `data_files` install path, dname is the source directory, and the
+        pattern is a glob pattern.
+    exclude: function
+        A function which takes a string filename and returns True if the
+        file should be excluded from package data and data files, False otherwise.
+
+    Notes
+    -----
+    We use specs so that we can find the files *after* the build
+    command has run.
+
+    The package data glob patterns should be relative paths from the package
+    folder containing the __init__.py file, which is given as the package
+    name.
+    e.g. `dict(foo=['bar/*', 'baz/**'])`
+
+    The data files directories should be absolute paths or relative paths
+    from the root directory of the repository.  Data files are specified
+    differently from `package_data` because we need a separate path entry
+    for each nested folder in `data_files`, and this makes it easier to
+    parse.
+    e.g. `('share/foo/bar', 'pkgname/bizz, '*')`
+    """
+    wrapped = [prerelease_cmd] if prerelease_cmd else []
+    if package_data_spec or data_files_spec:
+        wrapped.append('handle_files')
+
+    wrapper = functools.partial(_wrap_command, wrapped)
+    handle_files = _get_file_handler(package_data_spec, data_files_spec, exclude)
+    develop_handler = _get_develop_handler()
+
+    if 'bdist_egg' in sys.argv:
+        egg = wrapper(bdist_egg, strict=True)
     else:
-        # On other platforms you don't have things like PATHEXT to tell you
-        # what file suffixes are executable, so just pass on cmd as-is.
-        files = [cmd]
+        egg = bdist_egg_disabled
 
-    seen = set()
-    for dir in path:
-        dir = os.path.normcase(dir)
-        if dir not in seen:
-            seen.add(dir)
-            for thefile in files:
-                name = os.path.join(dir, thefile)
-                if _access_check(name, mode):
-                    return name
-    return None
+    is_repo = os.path.exists('.git')
 
+    cmdclass = dict(
+        build_py=wrapper(build_py, strict=is_repo),
+        bdist_egg=egg,
+        sdist=wrapper(sdist, strict=True),
+        handle_files=handle_files,
+    )
+
+    if bdist_wheel:
+        cmdclass['bdist_wheel'] = wrapper(bdist_wheel, strict=True)
+
+    cmdclass['develop'] = wrapper(develop_handler, strict=True)
+    return cmdclass
+
+
+@deprecated(deprecated_in="0.8", removed_in="1.0", current_version=__version__,
+            details="Use `npm_builder` and `wrap_installers`")
+def install_npm(path=None, build_dir=None, source_dir=None, build_cmd='build',
+                force=False, npm=None):
+    """Return a Command for managing an npm installation.
+
+    Note: The command is skipped if the `--skip-npm` flag is used.
+
+    Parameters
+    ----------
+    path: str, optional
+        The base path of the node package. Defaults to the current directory.
+    build_dir: str, optional
+        The target build directory.  If this and source_dir are given,
+        the JavaScript will only be build if necessary.
+    source_dir: str, optional
+        The source code directory.
+    build_cmd: str, optional
+        The npm command to build assets to the build_dir.
+    npm: str or list, optional.
+        The npm executable name, or a tuple of ['node', executable].
+    """
+    builder = npm_builder(path=path, build_dir=build_dir, source_dir=source_dir, build_cmd=build_cmd, force=force, npm=npm)
+
+    class NPM(BaseCommand):
+        description = 'install package.json dependencies using npm'
+
+        def run(self):
+            builder()
+
+    return NPM
 
 # ---------------------------------------------------------------------------
 # Private Functions
 # ---------------------------------------------------------------------------
 
-
+@deprecated(deprecated_in="0.8", removed_in="1.0", current_version=__version__,
+            details="Use `npm_builder` and `wrap_installers`")
 def _wrap_command(cmds, cls, strict=True):
     """Wrap a setup command
 
@@ -514,6 +651,8 @@ def _wrap_command(cmds, cls, strict=True):
     return WrappedCommand
 
 
+@deprecated(deprecated_in="0.8", removed_in="1.0", current_version=__version__,
+            details="Use `npm_builder` and `wrap_installers`")
 def _get_file_handler(package_data_spec, data_files_spec, exclude=None):
     """Get a package_data and data_files handler command.
     """
@@ -536,6 +675,8 @@ def _get_file_handler(package_data_spec, data_files_spec, exclude=None):
     return FileHandler
 
 
+@deprecated(deprecated_in="0.8", removed_in="1.0", current_version=__version__,
+            details="Use `npm_builder` and `wrap_installers`")
 def _get_develop_handler():
     """Get a handler for the develop command"""
     class _develop(develop):
@@ -657,6 +798,8 @@ def _get_files(file_patterns, top=None):
     return list(files)
 
 
+@deprecated(deprecated_in="0.8", removed_in="1.0", current_version=__version__,
+            details="Use `npm_builder` and `wrap_installers`")
 def _get_package_data(root, file_patterns=None):
     """Expand file patterns to a list of `package_data` paths.
 
