@@ -1,8 +1,23 @@
+import json
 import os
 import pathlib
+import sys
 from pytest import fixture
+from subprocess import run
 
 HERE = pathlib.Path(__file__).resolve()
+NAME = "jupyter_packaging_test_foo"
+
+PACKAGE_JSON = json.dumps(dict(
+    name="foo",
+    version="0.1.0",
+    scripts=dict(build=f"echo $(DATE) > {NAME}/generated.js")
+))
+
+
+@fixture(scope="session", autouse=True)
+def clear_pip_cache():
+    run([sys.executable, '-m', 'pip', 'cache', 'remove', 'jupyter_packaging'])
 
 
 @fixture
@@ -13,45 +28,63 @@ def pyproject_toml():
     root_path = HERE.joinpath("../..").resolve()
     return """
 [build-system]
-requires = ["jupyter_packaging@file://%s", "setuptools>=40.8.0", "wheel"]
+requires = ["jupyter_packaging@file://%s"]
 build-backend = "setuptools.build_meta"
 """ % str(root_path).replace(os.sep, '/')
 
+setup_cfg_maker = lambda name=NAME: """
+[metadata]
+name = {name}
+version = 0.1
+author = Jupyter Development Team
+author_email = jupyter@googlegroups.com
+url = http://jupyter.org
+description="foo package",
+long_description="long_description",
+long_description_content_type="text/markdown",
 
-setup = lambda name="jupyter_packaging_test_foo", data_files_spec=None, **kwargs: """
-from jupyter_packaging import create_cmdclass
+[options]
+zip_safe = False
+include_package_data = True
+py_modules = foo
+python_requires = >=3.6
+""".format(name=name)
+
+setup_maker = lambda name=NAME, data_files_spec=None, pre_dist=None, ensured_targets=None, skip_if_exists=None, **kwargs: """
+from jupyter_packaging import get_data_files, wrap_installers, npm_builder
 import setuptools
 import os
 
-
-name = "{name}"
-
-
 def exclude(filename):
     return os.path.basename(filename) == "exclude.py"
 
-cmdclass = create_cmdclass(
-    data_files_spec={data_files_spec},
-    exclude=exclude
-)
+data_files=get_data_files({data_files_spec}, exclude=exclude)
 
-setup_args = dict(
+cmdclass = wrap_installers(pre_dist={pre_dist}, ensured_targets={ensured_targets}, skip_if_exists={skip_if_exists})
+
+setuptools.setup(data_files=data_files, cmdclass=cmdclass, {setup_args})
+""".format(
     name=name,
-    version="0.1",
-    url="foo url",
-    author="foo author",
-    description="foo package",
-    long_description="long_description",
-    long_description_content_type="text/markdown",
-    cmdclass= cmdclass,
-    zip_safe=False,
-    include_package_data=True,
-    {setup_args}
+    data_files_spec=data_files_spec,
+    pre_dist=pre_dist or 'lambda: print',
+    ensured_targets=ensured_targets or [],
+    skip_if_exists=skip_if_exists or [],
+    setup_args="".join(['{}={},\n\t'.format(key, str(val)) for key, val in kwargs.items()])
 )
 
+setup_maker_deprecated = lambda name=NAME, data_files_spec=None, pre_dist=None, ensured_targets=None, **kwargs: """
+from jupyter_packaging import create_cmdclass, install_npm
+import setuptools
+import os
 
-if __name__ == "__main__":
-    setuptools.setup(**setup_args)
+def exclude(filename):
+    return os.path.basename(filename) == "exclude.py"
+
+
+cmdclass = create_cmdclass('jsdeps', data_files_spec={data_files_spec}, exclude=exclude)
+cmdclass['jsdeps'] = install_npm()
+
+setuptools.setup(cmdclass=cmdclass, {setup_args})
 """.format(
     name=name,
     data_files_spec=data_files_spec,
@@ -59,15 +92,13 @@ if __name__ == "__main__":
 )
 
 
-@fixture
-def make_package(tmp_path, pyproject_toml):
-    """A callable fixture that creates a mock python package
-    in tmp_path and returns the package directory
-    """
-    def stuff(
-        name="jupyter_packaging_test_foo",
+def make_package_base(tmp_path, pyproject_toml, setup_func=setup_maker, include_js=False):
+    def do_stuff(
+        name=NAME,
         data_files=None,
         data_files_spec=None,
+        ensured_targets=None,
+        skip_if_exists=None,
         py_module=False
     ):
         # Create the package directory.
@@ -77,12 +108,12 @@ def make_package(tmp_path, pyproject_toml):
         # What type of a package is this, single module or nested package?
         setup_args = {}
         if py_module:
-            setup_args.update({"py_module": ["jupyter_packaging_test_foo"]})
-            pkg.joinpath('jupyter_packaging_test_foo.py').write_text('print("hello, world!")')
+            setup_args.update({"py_module": [NAME]})
+            pkg.joinpath(f'{NAME}_foo.py').write_text('print("hello, world!")')
             pkg.joinpath('MANIFEST.in').write_text('recursive-include share *.*')
         else:
             setup_args.update({"packages": "setuptools.find_packages('.')"})
-            mod = pkg.joinpath('jupyter_packaging_test_foo')
+            mod = pkg.joinpath(NAME)
             mod.mkdir()
             mod.joinpath('__init__.py').write_text('')
             mod.joinpath('main.py').write_text('print("hello, world!")')
@@ -94,27 +125,70 @@ def make_package(tmp_path, pyproject_toml):
         # 1. Add a setup.py
         setuppy = pkg.joinpath("setup.py")
         # Pass the data_file spec to the setup.py
-        setup_content = setup(
+        pre_dist = None
+        if include_js:
+            pre_dist = 'npm_builder()'
+        setup_content = setup_func(
             name=name,
             data_files_spec=data_files_spec,
+            ensured_targets=ensured_targets,
+            skip_if_exists=skip_if_exists,
+            pre_dist=pre_dist,
             **setup_args
         )
         setuppy.write_text(setup_content)
 
         # 2. Add pyproject.toml to package.
-        with open(pkg.joinpath('pyproject.toml'), 'w') as fid:
-            fid.write(pyproject_toml)
+        pkg.joinpath('pyproject.toml').write_text(pyproject_toml)
 
-        # 3. Add datafiles content.
+        # 3. Add setup.cfg to package.
+        pkg.joinpath('setup.cfg').write_text(setup_cfg_maker(name=name))
+
+        # 4. Add datafiles content.
+        manifest = pkg / 'MANIFEST.in'
         if data_files:
             for datafile_path in data_files:
                 data_file = pkg.joinpath(datafile_path)
                 data_dir = data_file.parent
                 data_dir.mkdir(parents=True, exist_ok=True)
                 data_file.write_text("hello, world!")
-        return pkg
+                text = manifest.read_text()
+                manifest.write_text(f'{text}\ninclude {datafile_path}')
 
-    return stuff
+        # 5. Add package.json if needed.
+        if include_js:
+            package_json = pkg.joinpath("package.json")
+            package_json.write_text(PACKAGE_JSON, encoding='utf-8')
+
+            text = manifest.read_text()
+            manifest.write_text(f'{text}\ninclude {name}/generated.js')
+
+        return pkg
+    return do_stuff
+
+
+@fixture
+def make_package(tmp_path, pyproject_toml):
+    """A callable fixture that creates a mock python package
+    in tmp_path and returns the package directory
+    """
+    return make_package_base(tmp_path, pyproject_toml)
+
+
+@fixture
+def make_package_deprecated(tmp_path, pyproject_toml):
+    """A callable fixture that creates a mock python package
+    in tmp_path and returns the package directory
+    """
+    return make_package_base(tmp_path, pyproject_toml, setup_func=setup_maker_deprecated, include_js=True)
+
+
+@fixture
+def make_hybrid_package(tmp_path, pyproject_toml):
+    """A callable fixture that creates a mock hybrid package
+    in tmp_path and returns the package directory
+    """
+    return make_package_base(tmp_path, pyproject_toml, include_js=True)
 
 
 @fixture
