@@ -1,6 +1,6 @@
 import os
 
-from jupyter_packaging.setupbase import _get_data_files
+from jupyter_packaging.setupbase import get_data_files
 
 def test_empty_relative_path(tmpdir):
     tmpdir.mkdir('sub1').join('a.json').write('')
@@ -8,7 +8,7 @@ def test_empty_relative_path(tmpdir):
     spec = [
         ('my/target', '', '**/*.json')
     ]
-    res = _get_data_files(spec, None, top=str(tmpdir))
+    res = get_data_files(spec, top=str(tmpdir))
     assert sorted(res) == [
         ('my/target/sub1', ['sub1/a.json']),
         ('my/target/sub2', ['sub2/b.json']),
@@ -21,7 +21,7 @@ def test_dot_relative_path(tmpdir):
     spec = [
         ('my/target', '.', '**/*.json')
     ]
-    res = _get_data_files(spec, None, top=str(tmpdir))
+    res = get_data_files(spec, top=str(tmpdir))
     assert sorted(res) == [
         ('my/target/sub1', ['sub1/a.json']),
         ('my/target/sub2', ['sub2/b.json']),
@@ -32,9 +32,9 @@ def test_subdir_relative_path(tmpdir):
     tmpdir.mkdir('sub1').join('a.json').write('')
     tmpdir.mkdir('sub2').join('b.json').write('')
     spec = [
-        ('my/target', 'sub1', '**/*.json')
+        ('my/target', 'sub1', '**/[a-z].json')
     ]
-    res = _get_data_files(spec, None, top=str(tmpdir))
+    res = get_data_files(spec, top=str(tmpdir))
     assert sorted(res) == [
         ('my/target', ['sub1/a.json']),
     ]
@@ -46,7 +46,7 @@ def test_root_absolute_path(tmpdir):
     spec = [
         ('my/target', str(tmpdir), '**/*.json')
     ]
-    res = _get_data_files(spec, None, top=str(tmpdir))
+    res = get_data_files(spec, top=str(tmpdir))
     assert sorted(res) == [
         ('my/target/sub1', ['sub1/a.json']),
         ('my/target/sub2', ['sub2/b.json']),
@@ -59,7 +59,7 @@ def test_subdir_absolute_path(tmpdir):
     spec = [
         ('my/target', str(tmpdir.join('sub1')), '**/*.json')
     ]
-    res = _get_data_files(spec, None, top=str(tmpdir))
+    res = get_data_files(spec, top=str(tmpdir))
     assert sorted(res) == [
         ('my/target', ['sub1/a.json']),
     ]
@@ -72,7 +72,7 @@ def test_absolute_trailing_slash(tmpdir):
     spec = [
         ('my/target/', str(tmpdir) + '/', '**/*.*')
     ]
-    res = _get_data_files(spec, None, top=str(tmpdir))
+    res = get_data_files(spec, top=str(tmpdir))
     assert sorted(res) == [
         ('my/target/main/sub1', ['main/sub1/a.json']),
         ('my/target/main/sub2', ['main/sub2/b.json']),
@@ -85,7 +85,7 @@ def test_relative_trailing_slash(tmpdir):
     spec = [
         ('my/target/', 'main/', '**/*.json')
     ]
-    res = _get_data_files(spec, None, top=str(tmpdir))
+    res = get_data_files(spec, top=str(tmpdir))
     assert sorted(res) == [
         ('my/target/sub1', ['main/sub1/a.json']),
         ('my/target/sub2', ['main/sub2/b.json']),
@@ -99,7 +99,7 @@ def test_nested_source_dir(tmpdir):
     spec = [
         ('my/target', 'main/sub1', 'a.json')
     ]
-    res = _get_data_files(spec, None, top=str(tmpdir))
+    res = get_data_files(spec, top=str(tmpdir))
     assert sorted(res) == [
         ('my/target', ['main/sub1/a.json']),
     ]
